#pragma once
#include <vector>
#include "matrix.hpp"
#include <bitset>
#include <limits>
#include <optional>
#include <nlohmann/json.hpp>
#include "config.hpp"
#include "goap.hpp"

namespace ai {
  struct AIManager {
    nlohmann::json profile;

    std::unordered_map<std::string, Action> actions;
    std::unordered_map<std::string, State> states;
    std::unordered_map<std::string, std::vector<Action>> scripts;
  };

  void init(std::string config_path);

  Action config_action(nlohmann::json& profile, nlohmann::json& config);
  State config_state(nlohmann::json& profile, nlohmann::json& config);

  int state_id(std::string name);
  State load_state(std::string state_name);
  Action load_action(std::string action_name);
  std::vector<Action> load_script(std::string script_name);

  std::optional<Script> plan(std::string script_name, State start, State goal);
}
